==> myfaces-core-assembly-3.0.1-src.tar.gz: myfaces-core-module-3.0.1/api/src/main/java/jakarta/faces/component/ActionSource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package jakarta.faces.component;

import jakarta.faces.el.MethodBinding;
import jakarta.faces.event.ActionListener;

/**
 * see Javadoc of <a href="http://java.sun.com/javaee/javaserverfaces/1.2/docs/api/index.html">JSF Specification</a>
 */
public interface ActionSource
{
    /**
     * @deprecated Replaced by ActionSource2.getActionExpression
     */
    @Deprecated
    public MethodBinding getAction();

    /**
     * @deprecated Replaced by ActionSource2.setActionExpression
     */
    @Deprecated
    public void setAction(MethodBinding action);

    /**
     * @deprecated Replaced by getActionListeners
     */
    @Deprecated
    public MethodBinding getActionListener();

    /**
     * @deprecated  Replaced by addActionListener
     */
    @Deprecated
    public void setActionListener(MethodBinding actionListener);

    public boolean isImmediate();

    public void setImmediate(boolean immediate);

    public void addActionListener(ActionListener listener);

    public ActionListener[] getActionListeners();

    public void removeActionListener(ActionListener listener);
}

==> myfaces-core-assembly-4.1.0-src.tar.gz: myfaces-core-module-4.1.0/api/src/main/java/jakarta/faces/component/ActionSource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package jakarta.faces.component;

import jakarta.el.MethodExpression;

/**
 * see Javadoc of <a href="http://java.sun.com/javaee/javaserverfaces/1.2/docs/api/index.html">Faces Specification</a>
 */
public interface ActionSource
{
    public boolean isImmediate();

    public void setImmediate(boolean immediate);

    public void addActionListener(jakarta.faces.event.ActionListener listener);

    public jakarta.faces.event.ActionListener[] getActionListeners();

    public void removeActionListener(jakarta.faces.event.ActionListener listener);

    default MethodExpression getActionExpression()
    {
        throw new UnsupportedOperationException();
    }

    default void setActionExpression(MethodExpression action)
    {
        throw new UnsupportedOperationException();
    }
}
